AFRL labeling Fiducial Info (sarpy.annotation.afrl_elements.FiducialInfo)
=========================================================================

.. automodule:: sarpy.annotation.afrl_elements.FiducialInfo
    :members:
    :show-inheritance:
    :inherited-members:
